@@ -1,33 +1,54 @@
+/*
+ *	MPEG layer 3 tables source file
+ *
+ *	Copyright (c) 1999 Albert L Faber
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include "util.h"
 #include "tables.h"
 
-static HUFFBITS      t1HB[]   = {
+static const int      t1HB[]   = {
   1, 1, 
   1, 0};
 
-static HUFFBITS      t2HB[]   = {
+static const int      t2HB[]   = {
   1, 2, 1,
   3, 1, 1,
   3, 2, 0};
 
-static HUFFBITS      t3HB[]   = {
+static const int      t3HB[]   = {
   3, 2, 1,
   1, 1, 1,
   3, 2, 0};
 
-static HUFFBITS      t5HB[]   = {
+static const int      t5HB[]   = {
   1, 2, 6, 5,
   3, 1, 4, 4,
   7, 5, 7, 1,
   6, 1, 1, 0};
 
-static HUFFBITS      t6HB[]   = {
+static const int      t6HB[]   = {
   7, 3, 5, 1,
   6, 2, 3, 2,
   5, 4, 4, 1,
   3, 3, 2, 0};
 
-static HUFFBITS      t7HB[]   = {
+static const int      t7HB[]   = {
    1, 2,10,19,16,10,
    3, 3, 7,10, 5, 3,
   11, 4,13,17, 8, 4,
@@ -35,7 +56,7 @@ static HUFFBITS      t7HB[]   = {
    7, 6, 9,14, 3, 1,
    6, 4, 5, 3, 2, 0};
 
-static HUFFBITS      t8HB[]   = {
+static const int      t8HB[]   = {
   3, 4, 6, 18,12, 5,
   5, 1, 2, 16, 9, 3,
   7, 3, 5, 14, 7, 3,
@@ -43,7 +64,7 @@ static HUFFBITS      t8HB[]   = {
  13, 5, 8, 11, 5, 1,
  12, 4, 4,  1, 1, 0};
 
-static HUFFBITS      t9HB[]   = {
+static const int      t9HB[]   = {
   7, 5, 9, 14, 15, 7,
   6, 4, 5,  5,  6, 7,
   7, 6, 8,  8,  8, 5,
@@ -51,7 +72,7 @@ static HUFFBITS      t9HB[]   = {
  11, 7, 9,  6,  4, 1,
  14, 4, 6,  2,  6, 0};
 
-static HUFFBITS      t10HB[]   = {
+static const int      t10HB[]   = {
   1, 2, 10, 23, 35, 30, 12, 17,
   3, 3,  8, 12, 18, 21, 12,  7,
  11, 9, 15, 21, 32, 40, 19,  6,
@@ -61,7 +82,7 @@ static HUFFBITS      t10HB[]   = {
  14,13, 10, 11, 16,  6,  5,  1,
   9, 8,  7,  8,  4,  4,  2,  0};
 
-static HUFFBITS      t11HB[]   = {
+static const int      t11HB[]   = {
   3, 4, 10, 24, 34, 33, 21, 15,
   5, 3,  4, 10, 32, 17, 11, 10,
  11, 7, 13, 18, 30, 31, 20,  5,
@@ -71,7 +92,7 @@ static HUFFBITS      t11HB[]   = {
  14,12,  9, 13, 14,  9,  4,  1,
  11, 4,  6,  6,  6,  3,  2,  0};
 
-static HUFFBITS      t12HB[]   = {
+static const int      t12HB[]   = {
   9,  6, 16, 33, 41, 39, 38,26,
   7,  5,  6,  9, 23, 16, 26,11,
  17,  7, 11, 14, 21, 30, 10, 7,
@@ -81,7 +102,7 @@ static HUFFBITS      t12HB[]   = {
  27, 12, 11, 15, 10,  7,  4, 1,
  27, 12,  8, 12,  6,  3,  1, 0};
 
-static HUFFBITS      t13HB[]   = {
+static const int      t13HB[]   = {
   1,  5, 14, 21, 34, 51, 46, 71, 42, 52, 68, 52, 67, 44, 43, 19,
   3,  4, 12, 19, 31, 26, 44, 33, 31, 24, 32, 24, 31, 35, 22, 14,
  15, 13, 23, 36, 59, 49, 77, 65, 29, 40, 30, 40, 27, 33, 42, 16,
@@ -99,7 +120,7 @@ static HUFFBITS      t13HB[]   = {
  48, 23, 20, 39, 36, 35, 53, 21, 16, 23, 13, 10,  6,  1,  4,  2,
  16, 15, 17, 27, 25, 20, 29, 11, 17, 12, 16,  8,  1,  1,  0,  1};
 
-static HUFFBITS      t15HB[]   = {
+static const int      t15HB[]   = {
    7, 12, 18, 53, 47, 76,124,108, 89,123,108,119,107, 81,122, 63,
   13,  5, 16, 27, 46, 36, 61, 51, 42, 70, 52, 83, 65, 41, 59, 36,
   19, 17, 15, 24, 41, 34, 59, 48, 40, 64, 50, 78, 62, 80, 56, 33,
@@ -117,7 +138,7 @@ static HUFFBITS      t15HB[]   = {
  123, 60, 58, 53, 47, 43, 32, 22, 37, 24, 17, 12, 15, 10,  2,  1,
   71, 37, 34, 30, 28, 20, 17, 26, 21, 16, 10,  6,  8,  6,  2,  0};
 
-static HUFFBITS      t16HB[]   = {
+static const int      t16HB[]   = {
    1,   5, 14, 44, 74, 63, 110, 93, 172, 149, 138, 242, 225, 195, 376, 17,
    3,   4, 12, 20, 35, 62,  53, 47,  83,  75,  68, 119, 201, 107, 207,  9,
   15,  13, 23, 38, 67, 58, 103, 90, 161,  72, 127, 117, 110, 209, 206, 16,
@@ -135,7 +156,7 @@ static HUFFBITS      t16HB[]   = {
  377, 369,102,187,726,722, 358,711, 709, 866,1734, 871,3458, 870, 434,  0,
   12,  10,  7, 11, 10, 17,  11,  9,  13,  12,  10,   7,   5,   3,   1,  3};
 
-static HUFFBITS      t24HB[]   = {
+static const int      t24HB[]   = {
    15, 13, 46, 80, 146, 262, 248, 434, 426, 669, 653, 649, 621, 517, 1032, 88,
    14, 12, 21, 38,  71, 130, 122, 216, 209, 198, 327, 345, 319, 297,  279, 42,
    47, 22, 41, 74,  68, 128, 120, 221, 207, 194, 182, 340, 315, 295,  541, 18,
@@ -153,42 +174,42 @@ static HUFFBITS      t24HB[]   = {
  1033,280,278,274, 267, 264, 259, 382, 378, 372, 367, 363, 360, 358,  356,  0,
    43, 20, 19, 17,  15,  13,  11,   9,   7,   6,   4,   7,   5,   3,    1,  3};
 
-static HUFFBITS      t32HB[]   = {
+static const int      t32HB[]   = {
   1 << 0,  5 << 1,  4 << 1,  5 << 2,  6 << 1,  5 << 2,  4 << 2,  4 << 3,
   7 << 1,  3 << 2,  6 << 2,  0 << 3,  7 << 2,  2 << 3,  3 << 3,  1 << 4};
 
-static HUFFBITS      t33HB[]   = {
+static const int      t33HB[]   = {
  15 << 0, 14 << 1, 13 << 1, 12 << 2, 11 << 1, 10 << 2,  9 << 2,  8 << 3,
   7 << 1,  6 << 2,  5 << 2,  4 << 3,  3 << 2,  2 << 3,  1 << 3,  0 << 4};
 
 
-unsigned char t1l[] = {
+const  char t1l[] = {
  1,  4, 
  3,  5};
 
-unsigned char t2l[] = {
+const  char t2l[] = {
  1,  4,  7, 
  4,  5,  7, 
  6,  7,  8};
 
-unsigned char t3l[] = {
+const  char t3l[] = {
  2,  3,  7, 
  4,  4,  7, 
  6,  7,  8};
 
-unsigned char t5l[] = {
+const  char t5l[] = {
  1,  4,  7,  8, 
  4,  5,  8,  9, 
  7,  8,  9, 10, 
  8,  8,  9, 10};
 
-unsigned char t6l[] = {
+const  char t6l[] = {
  3,  4,  6,  8, 
  4,  4,  6,  7, 
  5,  6,  7,  8, 
  7,  7,  8,  9};
 
-unsigned char t7l[] = {
+const  char t7l[] = {
  1,  4,  7,  9,  9, 10, 
  4,  6,  8,  9,  9, 10, 
  7,  7,  9, 10, 10, 11, 
@@ -196,7 +217,7 @@ unsigned char t7l[] = {
  8,  9, 10, 11, 11, 12, 
  9, 10, 11, 12, 12, 12};
 
-unsigned char t8l[] = {
+const  char t8l[] = {
  2,  4,  7,  9,  9, 10, 
  4,  4,  6, 10, 10, 10, 
  7,  6,  8, 10, 10, 11, 
@@ -204,7 +225,7 @@ unsigned char t8l[] = {
  9,  9, 10, 11, 12, 12, 
 10, 10, 11, 11, 13, 13};
 
-unsigned char t9l[] = {
+const  char t9l[] = {
  3,  4,  6,  7,  9, 10, 
  4,  5,  6,  7,  8, 10, 
  5,  6,  7,  8,  9, 10, 
@@ -212,7 +233,7 @@ unsigned char t9l[] = {
  8,  8,  9,  9, 10, 11, 
  9,  9, 10, 10, 11, 11};
 
-unsigned char t10l[] = {
+const  char t10l[] = {
  1,  4,  7,  9, 10, 10, 10, 11, 
  4,  6,  8,  9, 10, 11, 10, 10, 
  7,  8,  9, 10, 11, 12, 11, 11, 
@@ -222,7 +243,7 @@ unsigned char t10l[] = {
  9, 10, 11, 12, 12, 12, 13, 13, 
 10, 10, 11, 12, 12, 13, 13, 13};
 
-unsigned char t11l[] = {
+const  char t11l[] = {
  2,  4,  6,  8,  9, 10,  9, 10, 
  4,  5,  6,  8, 10, 10,  9, 10, 
  6,  7,  8,  9, 10, 11, 10, 10, 
@@ -232,7 +253,7 @@ unsigned char t11l[] = {
  9,  9,  9, 10, 11, 12, 12, 12, 
  9,  9, 10, 11, 12, 12, 12, 12};
 
-unsigned char t12l[] = {
+const  char t12l[] = {
  4,  4,  6,  8,  9, 10, 10, 10, 
  4,  5,  6,  7,  9,  9, 10, 10, 
  6,  6,  7,  8,  9, 10,  9, 10, 
@@ -242,7 +263,7 @@ unsigned char t12l[] = {
  9,  9,  9, 10, 10, 11, 11, 12, 
 10, 10, 10, 11, 11, 11, 11, 12};
 
-unsigned char t13l[] = {
+const  char t13l[] = {
  1,  5,  7,  8,  9, 10, 10, 11, 10, 11, 12, 12, 13, 13, 14, 14, 
  4,  6,  8,  9, 10, 10, 11, 11, 11, 11, 12, 12, 13, 14, 14, 14, 
  7,  8,  9, 10, 11, 11, 12, 12, 11, 12, 12, 13, 13, 14, 15, 15, 
@@ -260,7 +281,7 @@ unsigned char t13l[] = {
 14, 14, 14, 15, 15, 15, 17, 16, 16, 19, 17, 17, 17, 19, 18, 18, 
 13, 14, 15, 16, 16, 16, 17, 16, 17, 17, 18, 18, 21, 20, 21, 18};
 
-unsigned char t15l[] = {
+const  char t15l[] = {
  3,  5,  6,  8,  8,  9, 10, 10, 10, 11, 11, 12, 12, 12, 13, 14, 
  5,  5,  7,  8,  9,  9, 10, 10, 10, 11, 11, 12, 12, 12, 13, 13, 
  6,  7,  7,  8,  9,  9, 10, 10, 10, 11, 11, 12, 12, 13, 13, 13, 
@@ -278,7 +299,7 @@ unsigned char t15l[] = {
 13, 13, 13, 13, 13, 13, 13, 13, 14, 14, 14, 14, 15, 15, 14, 15, 
 13, 13, 13, 13, 13, 13, 13, 14, 14, 14, 14, 14, 15, 15, 15, 15};
 
-unsigned char t16_5l[] = {
+const  char t16_5l[] = {
  1,  5,  7,  9, 10, 10, 11, 11, 12, 12, 12, 13, 13, 13, 14, 11, 
  4,  6,  8,  9, 10, 11, 11, 11, 12, 12, 12, 13, 14, 13, 14, 11, 
  7,  8,  9, 10, 11, 11, 12, 12, 13, 12, 13, 13, 13, 14, 14, 12, 
@@ -296,7 +317,7 @@ unsigned char t16_5l[] = {
 14, 15, 13, 14, 16, 16, 15, 16, 16, 17, 18, 17, 19, 17, 16, 14, 
 11, 11, 11, 12, 12, 13, 13, 13, 14, 14, 14, 14, 14, 14, 14, 12};
 
-unsigned char t16l[] = {
+const  char t16l[] = {
  1,  5,  7,  9, 10, 10, 11, 11, 12, 12, 12, 13, 13, 13, 14, 10, 
  4,  6,  8,  9, 10, 11, 11, 11, 12, 12, 12, 13, 14, 13, 14, 10, 
  7,  8,  9, 10, 11, 11, 12, 12, 13, 12, 13, 13, 13, 14, 14, 11, 
@@ -314,7 +335,7 @@ unsigned char t16l[] = {
 14, 15, 13, 14, 16, 16, 15, 16, 16, 17, 18, 17, 19, 17, 16, 13, 
 10, 10, 10, 11, 11, 12, 12, 12, 13, 13, 13, 13, 13, 13, 13, 10};
 
-unsigned char t24l[] = {
+const  char t24l[] = {
  4,  5,  7,  8,  9, 10, 10, 11, 11, 12, 12, 12, 12, 12, 13, 10, 
  5,  6,  7,  8,  9, 10, 10, 11, 11, 11, 12, 12, 12, 12, 12, 10, 
  7,  7,  8,  9,  9, 10, 10, 11, 11, 11, 11, 12, 12, 12, 13,  9, 
@@ -332,16 +353,16 @@ unsigned char t24l[] = {
 13, 12, 12, 12, 12, 12, 12, 13, 13, 13, 13, 13, 13, 13, 13, 10, 
  9,  9,  9,  9,  9,  9,  9,  9,  9,  9,  9, 10, 10, 10, 10,  6};
 
-unsigned char t32l[]  = {
+const  char t32l[]  = {
   1+0,  4+1,  4+1,  5+2,  4+1,  6+2,  5+2,  6+3,
   4+1,  5+2,  5+2,  6+3,  5+2,  6+3,  6+3,  6+4};
 
-unsigned char t33l[]  = {
+const  char t33l[]  = {
   4+0,  4+1,  4+1,  4+2,  4+1,  4+2,  4+2,  4+3,
   4+1,  4+2,  4+2,  4+3,  4+2,  4+3,  4+3,  4+4};
 
 
-struct huffcodetab ht[HTN] =
+const struct huffcodetab ht[HTN] =
 {
   /* xlen, linmax, table, hlen */
   { 0,   0,NULL,NULL},
@@ -387,7 +408,7 @@ struct huffcodetab ht[HTN] =
 
 
 
-FLOAT8 psy_data[] =
+const FLOAT8 psy_data[] =  // strange data type, really, it looks like a core dump
 {48000.0, 61,
  0, 1, 24.5, 4.532, 0.970, 0.000,
  1, 1, 24.5, 4.532, 0.755, 0.469,
