@@ -3,26 +3,28 @@
  *
  *	Copyright (c) 1999 Mark Taylor
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
+
 #include <assert.h>
 #include "util.h"
 #include "l3side.h"
 #include "quantize.h"
 #include "reservoir.h"
-#include "quantize-pvt.h"
+#include "quantize_pvt.h"
 #include "gtkanal.h"
 
 
@@ -47,7 +49,7 @@
 #  define QUANTFAC(rx)  adj43asm[rx]
 #  define ROUNDFAC -0.0946
 #  define XRPOW_FTOI(src, dest) \
-     asm ("fistpl %0 " : "=m"(dest) : "t"(src) : "st")
+     __asm__ ("fistpl %0 " : "=m"(dest) : "t"(src) : "st")
 #elif defined (USE_MSC_ASM)
 #  define QUANTFAC(rx)  adj43asm[rx]
 #  define ROUNDFAC -0.0946
@@ -236,7 +238,7 @@ int find_scalefac(FLOAT8 *xr,FLOAT8 *xr34,int sfb,
 
 */
 int compute_scalefacs_short(int sf[SBPSY_s][3],gr_info *cod_info,
-int scalefac[SBPSY_s][3],unsigned int sbg[3])
+int scalefac[SBPSY_s][3],int sbg[3])
 {
   int maxrange,maxrange1,maxrange2,maxover;
   int sfb,i;
@@ -266,7 +268,7 @@ int scalefac[SBPSY_s][3],unsigned int sbg[3])
     maxsf1 = Max(maxsf1-maxrange1*ifqstep,maxsf2-maxrange2*ifqstep);
     sbg[i]=0;
     if (minsf >0 ) sbg[i] = floor(.125*minsf + .001);
-    if (maxsf1 > 0)  sbg[i]  = Max(sbg[i],maxsf1/8 + (maxsf1 % 8 != 0));
+    if (maxsf1 > 0)  sbg[i] = Max(sbg[i],(maxsf1/8 + (maxsf1 % 8 != 0)));
     if (sbg[i] > 7) sbg[i]=7;
 
 
@@ -292,9 +294,9 @@ int scalefac[SBPSY_s][3],unsigned int sbg[3])
 
 
 
-int max_range_short[SBPSY_s]=
+const int max_range_short[SBPSY_s]=
 {15, 15, 15, 15, 15, 15 ,  7,    7,    7,    7,   7,     7 };
-int max_range_long[SBPSY_l]=
+const int max_range_long[SBPSY_l]=
 {15,   15,  15,  15,  15,  15,  15,  15,  15,  15,  15,   7,   7,   7,   7,   7,   7,   7,    7,    7,    7};
 
 
@@ -375,7 +377,7 @@ VBR_quantize_granule(lame_global_flags *gfp,
   }
   
   /* quantize xr34 */
-  cod_info->part2_3_length = count_bits(gfp,l3_enc,xr34,cod_info);
+  cod_info->part2_3_length = count_bits(gfc,l3_enc,xr34,cod_info);
   if (cod_info->part2_3_length >= LARGE_BITS) return;
   cod_info->part2_3_length += cod_info->part2_length;
 
@@ -740,6 +742,7 @@ VBR_quantize(lame_global_flags *gfp,
   /* from quantize.c VBR algorithm */
   /*static const FLOAT8 dbQ[10]=
    {-5.5,-4.25,-3.0,-2.50, -1.75, -.75, -.5, -.25, .25, .75};*/
+  /* a third dbQ table ?!? */
   static const FLOAT8 dbQ[10]=
   {-6.06,-4.4,-2.9,-1.57, -0.4, 0.61, 1.45, 2.13, 2.65, 3.0};
   
@@ -748,7 +751,6 @@ VBR_quantize(lame_global_flags *gfp,
   l3_side = &gfc->l3_side;
   gfc->ATH_vbrlower = (4-gfp->VBR_q)*4.0; 
   if (gfc->ATH_vbrlower < 0) gfc->ATH_vbrlower=0;
-  iteration_init(gfp,l3_side,l3_enc);
 
 
   /* now find out: if the frame can be considered analog silent
@@ -773,6 +775,15 @@ VBR_quantize(lame_global_flags *gfp,
       cod_info = &l3_side->gr[gr].ch[ch].tt;
       cod_info->part2_3_length=LARGE_BITS;
       
+      if (cod_info->block_type == SHORT_TYPE) {
+          cod_info->sfb_lmax = 0; /* No sb*/
+          cod_info->sfb_smax = 0;
+      } else {
+          /* MPEG 1 doesnt use last scalefactor band */
+          cod_info->sfb_lmax = SBPSY_l;
+          cod_info->sfb_smax = SBPSY_s;    /* No sb */
+      }
+      
       /* quality setting */
       masking_lower_db = dbQ[gfp->VBR_q];
       if (pe[gr][ch]>750) {
@@ -781,7 +792,7 @@ VBR_quantize(lame_global_flags *gfp,
       gfc->masking_lower = pow(10.0,masking_lower_db/10);
       
       /* masking thresholds */
-      over_ath = calc_xmin(gfp,xr[gr][ch],ratio[gr]+ch,cod_info,l3_xmin[gr]+ch);
+      over_ath = calc_xmin(gfp,xr[gr][ch],&ratio[gr][ch],cod_info,&l3_xmin[gr][ch]);
       
       /* if there are bands with more energy than the ATH 
        * then we say the frame is not analog silent */
@@ -935,48 +946,33 @@ VBR_quantize(lame_global_flags *gfp,
   } while (!bits_ok);
   
 
-  /* find optimal scalefac storage.  Cant be done above because
-   * might enable scfsi which breaks the interation loops */
-  totbits=0;
-  for (gr = 0; gr < gfc->mode_gr; gr++) {
-    for (ch = 0; ch < gfc->stereo; ch++) {
-      best_scalefac_store(gfp,gr, ch, l3_enc, l3_side, scalefac);
-      totbits += l3_side->gr[gr].ch[ch].tt.part2_3_length;
-    }
-  }
 
-
-
-  
   if (gfp->gtkflag) {
     for (gr = 0; gr < gfc->mode_gr; gr++) {
       for (ch = 0; ch < gfc->stereo; ch++) {
-        III_psy_xmin l3_xmin;
-        calc_noise_result noise_info;
-        FLOAT8 noise[4];
-        FLOAT8 xfsf[4][SBMAX_l];
-        FLOAT8 distort[4][SBMAX_l];
-
         cod_info = &l3_side->gr[gr].ch[ch].tt;
 
         /* recompute allowed noise with no 'masking_lower' for
          * frame analyzer */
         gfc->masking_lower=1.0;
-        cod_info = &l3_side->gr[gr].ch[ch].tt;
-        calc_xmin( gfp,xr[gr][ch], &ratio[gr][ch], cod_info, &l3_xmin);
-
-        calc_noise( gfp, xr[gr][ch], l3_enc[gr][ch], cod_info, 
-                    xfsf,distort, &l3_xmin, &scalefac[gr][ch], &noise_info);
-        noise[0] = noise_info.over_count;
-        noise[1] = noise_info.max_noise;
-        noise[2] = noise_info.over_noise;
-        noise[3] = noise_info.tot_noise;
-
-        set_pinfo (gfp, cod_info, &ratio[gr][ch], &scalefac[gr][ch], xr[gr][ch], xfsf, noise, gr, ch);
+        set_pinfo (gfp, cod_info, &ratio[gr][ch], &scalefac[gr][ch], xr[gr][ch], l3_enc[gr][ch], gr, ch);
       }
     }
   }
 
+  
+
+
+  /* find optimal scalefac storage.  Cant be done above because
+   * might enable scfsi which breaks the interation loops */
+  totbits=0;
+  for (gr = 0; gr < gfc->mode_gr; gr++) {
+    for (ch = 0; ch < gfc->stereo; ch++) {
+      best_scalefac_store(gfc, gr, ch, l3_enc, l3_side, scalefac);
+      totbits += l3_side->gr[gr].ch[ch].tt.part2_3_length;
+    }
+  }
+
 
   
 
